
.. image:: https://readthedocs.org/projects/zelfred/badge/?version=latest
    :target: https://zelfred.readthedocs.io/en/latest/
    :alt: Documentation Status

.. image:: https://github.com/MacHu-GWU/zelfred-project/workflows/CI/badge.svg
    :target: https://github.com/MacHu-GWU/zelfred-project/actions?query=workflow:CI

.. image:: https://codecov.io/gh/MacHu-GWU/zelfred-project/branch/main/graph/badge.svg
    :target: https://codecov.io/gh/MacHu-GWU/zelfred-project

.. image:: https://img.shields.io/pypi/v/zelfred.svg
    :target: https://pypi.python.org/pypi/zelfred

.. image:: https://img.shields.io/pypi/l/zelfred.svg
    :target: https://pypi.python.org/pypi/zelfred

.. image:: https://img.shields.io/pypi/pyversions/zelfred.svg
    :target: https://pypi.python.org/pypi/zelfred

.. image:: https://img.shields.io/badge/Release_History!--None.svg?style=social
    :target: https://github.com/MacHu-GWU/zelfred-project/blob/main/release-history.rst

.. image:: https://img.shields.io/badge/STAR_Me_on_GitHub!--None.svg?style=social
    :target: https://github.com/MacHu-GWU/zelfred-project

------

.. image:: https://img.shields.io/badge/Link-Document-blue.svg
    :target: https://zelfred.readthedocs.io/en/latest/

.. image:: https://img.shields.io/badge/Link-API-blue.svg
    :target: https://zelfred.readthedocs.io/en/latest/py-modindex.html

.. image:: https://img.shields.io/badge/Link-Install-blue.svg
    :target: `install`_

.. image:: https://img.shields.io/badge/Link-GitHub-blue.svg
    :target: https://github.com/MacHu-GWU/zelfred-project

.. image:: https://img.shields.io/badge/Link-Submit_Issue-blue.svg
    :target: https://github.com/MacHu-GWU/zelfred-project/issues

.. image:: https://img.shields.io/badge/Link-Request_Feature-blue.svg
    :target: https://github.com/MacHu-GWU/zelfred-project/issues

.. image:: https://img.shields.io/badge/Link-Download-blue.svg
    :target: https://pypi.org/pypi/zelfred#files


Welcome to ``zelfred`` Documentation
==============================================================================
.. image:: https://zelfred.readthedocs.io/en/latest/_static/zelfred-logo.png
    :target: https://zelfred.readthedocs.io/

``zelfred`` is a framework for building interactive applications similar to `Alfred Workflow <https://www.alfredapp.com/workflows/>`_, but in Python and for the terminal. It is free, open source, and cross-platform.

You can view sample applications in the `App Gallery <https://zelfred.readthedocs.io/en/latest/02-App-Gallery/index.html>`_.


.. _install:

Install
------------------------------------------------------------------------------

``zelfred`` is released on PyPI, so all you need is to:

.. code-block:: console

    $ pip install zelfred

To upgrade to latest version:

.. code-block:: console

    $ pip install --upgrade zelfred
